# Drupal OpenAI Client

Drupal OpenAI Client is a module for Drupal that provides integration with the
OpenAI API, allowing for the use of natural language processing and artificial
intelligence in your Drupal site. This module allows users to configure their
OpenAI API token and view available models.

This module add the `AI conversation` content type to chat with the default
model.

## Disclaimer

This module has been created by Pedro Pelaez to connect with ChatGPT, a product
of OpenAI. We have no affiliation with OpenAI and does not claim any ownership
or responsibility for the ChatGPT product. We respect OpenAI's intellectual
property rights and are using ChatGPT solely for the purpose of providing a
useful feature to our users. Any issues or concerns related to ChatGPT should
be directed to ([OpenAI's support team](https://help.openai.com/en/)).

## Installation

To install this module, use composer:

```bash
composer require drupal/openai_client
```

## Configuration

Go to the "OpenAI Client" configuration page
(/admin/config/system/openai-client) to set your OpenAI API token. After
setting the API token, available models will be displayed on the configuration
page. Then, configure the default model to use in chat.

## Usage

This module integrates with the OpenAI API,
adding the AI conversation content type to chat with the default model
and an example of an image creator form, in `/openai-client/create-image`, to
try it you need `openai_client create image form` permission.

To use the features of the OpenAI API in your site, you will need to create
custom functionality or integrate with other modules.

The module public the `openai_client.wrapper` service with the next interface:

```php
  /**
   * Get a new client with token set.
   *
   * @param string $token
   *   Optional API token, by default use the module set token.
   *
   * @return \OpenAI\Client
   */
  public function getClient(string $token = ''): Client

  /**
   * Get available AI models.
   *
   * @return array
   */
  public function getModels(): array;

  /**
   * Has module API token set?
   *
   * @return bool
   */
  public function hasToken():bool;

  /**
   * Do a direct query to default chat model and return the response text.
   *
   * @param string $prompt
   *
   * @return string
   */
  public function fastChatQuery(string $prompt): string;

  /**
   * Get default module chat model.
   *
   * @return array|mixed|null
   */
  public function getDefaultModel();

  /**
   * Generate a new image from prompt.
   *
   * @param string $prompt
   *   Text prompt.
   * @param int $amount
   *   Images size, the service class define constants to it. Smaller sizes are
   *   faster to generate.
   * @param string $size
   *   You can request 1-10 images at a time.
   *
   * @return array|\array{created: int, data: array}
   */
  public function imageCreate(string $prompt, int $amount = 1, string $size =
  self::IMAGE_SIZE_256);

  /**
   * Get valid image sizes to create.
   *
   * @return string[]
   */
  public static function getImageSizes();
```

## Requirements

- Drupal 10
- An OpenAI API token

## Credits

- This module was created by Pedro Pelaez.
- This README.md file was generated by ChatGPT, of OpenAI, and revised manually.
- This module use the library ([thephpleague/commonmark](https://github.com/thephpleague/commonmark))
- This module use the library ([openai-php/client](https://github.com/openai-php/client))

## Maintainers

- Pedro Pelaez ([@psf_](https://www.drupal.org/u/psf_))
- Jordan Koplowicz ([@koppie](https://www.drupal.org/u/koppie))
